==> oci-1.3.13.tar.gz: oci-1.3.13/src/oci/identity/models/create_customer_secret_key_details.py <==
# coding: utf-8
# Copyright (c) 2016, 2018, Oracle and/or its affiliates. All rights reserved.


from ...util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from ...decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateCustomerSecretKeyDetails(object):

    def __init__(self, **kwargs):
        """
        Initializes a new CreateCustomerSecretKeyDetails object with values from values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateCustomerSecretKeyDetails.
        :type display_name: str

        """
        self.swagger_types = {
            'display_name': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName'
        }

        self._display_name = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateCustomerSecretKeyDetails.
        The name you assign to the secret key during creation. Does not have to be unique, and it's changeable.


        :return: The display_name of this CreateCustomerSecretKeyDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateCustomerSecretKeyDetails.
        The name you assign to the secret key during creation. Does not have to be unique, and it's changeable.


        :param display_name: The display_name of this CreateCustomerSecretKeyDetails.
        :type: str
        """
        self._display_name = display_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other

==> oci-2.2.14.tar.gz: oci-2.2.14/src/oci/identity/models/create_customer_secret_key_details.py <==
# coding: utf-8
# Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateCustomerSecretKeyDetails(object):
    """
    CreateCustomerSecretKeyDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateCustomerSecretKeyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this CreateCustomerSecretKeyDetails.
        :type display_name: str

        """
        self.swagger_types = {
            'display_name': 'str'
        }

        self.attribute_map = {
            'display_name': 'displayName'
        }

        self._display_name = None

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this CreateCustomerSecretKeyDetails.
        The name you assign to the secret key during creation. Does not have to be unique, and it's changeable.


        :return: The display_name of this CreateCustomerSecretKeyDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateCustomerSecretKeyDetails.
        The name you assign to the secret key during creation. Does not have to be unique, and it's changeable.


        :param display_name: The display_name of this CreateCustomerSecretKeyDetails.
        :type: str
        """
        self._display_name = display_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
